summaryrefslogtreecommitdiff
path: root/bitmap.h
diff options
context:
space:
mode:
authorThomas Günther <tom@toms-cafe.de>2007-09-22 01:01:10 +0200
committerThomas Günther <tom@toms-cafe.de>2007-09-22 01:01:10 +0200
commit135a8c9447ca19c4d609373b228bd096a2ae2ab8 (patch)
tree1f24e7f3d0d4531d1a5bd705b89c40e7c3c29d33 /bitmap.h
parentb39a6bf3e7add336dbb127394e8c611ec1d29cd6 (diff)
downloadvdr-plugin-spider-135a8c9447ca19c4d609373b228bd096a2ae2ab8.tar.gz
vdr-plugin-spider-135a8c9447ca19c4d609373b228bd096a2ae2ab8.tar.bz2
Added namespaces
Diffstat (limited to 'bitmap.h')
-rw-r--r--bitmap.h48
1 files changed, 27 insertions, 21 deletions
diff --git a/bitmap.h b/bitmap.h
index a7cfa97..dd3a8c3 100644
--- a/bitmap.h
+++ b/bitmap.h
@@ -17,7 +17,7 @@
* with this program; if not, write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*
- * $Id: bitmap.h 87 2007-06-22 22:37:36Z tom $
+ * $Id: bitmap.h 95 2007-09-21 23:01:10Z tom $
*/
#ifndef VDR_SPIDER_BITMAP_H
@@ -29,33 +29,39 @@
#include <vdr/osd.h>
-/** --- class Bitmap ------------------------------------------------------- **/
-
-class Bitmap : public cBitmap
+namespace SpiderPlugin
{
-public:
- /** Constructor */
- Bitmap(int width, int height);
+ //--- class SpiderPlugin::Bitmap ---------------------------------------------
+
+ /** Plugin-specific version of the bitmap class */
+ class Bitmap : public cBitmap
+ {
+ public:
+
+ /** Constructor */
+ Bitmap(int width, int height);
+
+ /** Constructor for a bitmap with frame */
+ Bitmap(int width, int height, tColor frameColor, tColor backgroundColor);
- /** Constructor for a bitmap with frame */
- Bitmap(int width, int height, tColor frameColor, tColor backgroundColor);
+ /** Constructor for a bitmap read from an xpm file */
+ Bitmap(int width, int height, const char* dir, const char* name);
- /** Constructor for a bitmap read from an xpm file */
- Bitmap(int width, int height, const char* dir, const char* name);
+ /** Constructor for a card bitmap read from an xpm file */
+ Bitmap(int width, int height, const char* dir,
+ const char* suit, const char* rank);
- /** Constructor for a card bitmap read from an xpm file */
- Bitmap(int width, int height, const char* dir,
- const char* suit, const char* rank);
+ /** Write a text into the bitmap */
+ void text(const char* text, bool centered = true);
- /** Write a text into the bitmap */
- void text(const char* text, bool centered = true);
+ /** Draw a frame into the bitmap */
+ void frame(int x1, int y1, int x2, int y2, tColor frameColor);
- /** Draw a frame into the bitmap */
- void frame(int x1, int y1, int x2, int y2, tColor frameColor);
+ /** Load a bitmap from an xpm file - taken from ElchiAIO4d patch */
+ bool loadXpm(const char* FileName, tColor NoneColor = clrTransparent);
+ };
- /** Load a bitmap from an xpm file - taken from ElchiAIO4d patch */
- bool loadXpm(const char* FileName, tColor NoneColor = clrTransparent);
-};
+} // namespace SpiderPlugin
#endif // VDR_SPIDER_BITMAP_H